==> itext-src-1.4.5.tar.gz: com/lowagie/tools/arguments/PageSelectorToolArgument.java <==
/*
 * $Id: PageSelectorToolArgument.java,v 1.4 2006/08/24 10:28:25 blowagie Exp $
 * $Name:  $
 *
 * Copyright 2005 by Carsten Hammer
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the License.
 *
 * The Original Code is 'iText, a free JAVA-PDF library'.
 *
 * The Initial Developer of the Original Code is Bruno Lowagie. Portions created by
 * the Initial Developer are Copyright (C) 1999, 2000, 2001, 2002 by Bruno Lowagie.
 * All Rights Reserved.
 * Co-Developer of the code is Paulo Soares. Portions created by the Co-Developer
 * are Copyright (C) 2000, 2001, 2002 by Paulo Soares. All Rights Reserved.
 *
 * Contributor(s): all the names of the contributors are added in the source code
 * where applicable.
 *
 * Alternatively, the contents of this file may be used under the terms of the
 * LGPL license (the "GNU LIBRARY GENERAL PUBLIC LICENSE"), in which case the
 * provisions of LGPL are applicable instead of those above.  If you wish to
 * allow use of your version of this file only under the terms of the LGPL
 * License and not to allow others to use your version of this file under
 * the MPL, indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by the LGPL.
 * If you do not delete the provisions above, a recipient may use your version
 * of this file under either the MPL or the GNU LIBRARY GENERAL PUBLIC LICENSE.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the MPL as stated above or under the terms of the GNU
 * Library General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Library general Public License for more
 * details.
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://www.lowagie.com/iText/
 */
package com.lowagie.tools.arguments;

import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;

import com.lowagie.tools.plugins.AbstractTool;

/**
 * Argument that allows you to select a (set of) page(s).
 */
public class PageSelectorToolArgument
    extends ToolArgument {
//  public final static String PROPERTYFILENAME = "inputfilename";
  public final static String PROPERTYPAGESELECTIONSTRING =
      "pageselectionstring";

  public PageSelectorToolArgument(AbstractTool tool, String name,
                                  String description,
                                  String classname) {
    super(tool, name, description, classname);

  }

  public void actionPerformed(ActionEvent e) {
    if (jDialog1 != null) {
      jDialog1.show();
    }
  }

  public Object getArgument() throws InstantiationException {
    if (value == null) {
      return null;
    }
    return value;
  }

  public void propertyChange(PropertyChangeEvent evt) {
    String propertyname = evt.getPropertyName();
    if (jDialog1 == null) {
      actionPerformed(null);
    }
    if (propertyname == null) {
      return;
    }
    else if (propertyname.equals(name)) {
      String filename = (String) evt.getNewValue();
      if(jDialog1!=null)jDialog1.hide();
      jDialog1 = new PageSelectionTableDialog(tool.getInternalFrame());
      jDialog1.show();
      jDialog1.addPropertyChangeListener(this);
      jDialog1.setDataModel(new PageTableModel(filename));
      jDialog1.setTitle(filename);
    }
    else if (propertyname.equals(PROPERTYPAGESELECTIONSTRING)) {
      String pageselectionstring = (String) evt.getNewValue();
      System.out.print(" Oldvalue:" + evt.getOldValue());
      System.out.println(" Newvalue:" + pageselectionstring);
      setValue(pageselectionstring, PROPERTYPAGESELECTIONSTRING);
    }
  }

  PageSelectionTableDialog jDialog1 = null;
}

==> itext-src-1.4.8.tar.gz: com/lowagie/tools/arguments/PageSelectorToolArgument.java <==
/*
 * $Id: PageSelectorToolArgument.java,v 1.5 2006/09/15 00:40:10 xlv Exp $
 * $Name:  $
 *
 * Copyright 2005 by Carsten Hammer
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the License.
 *
 * The Original Code is 'iText, a free JAVA-PDF library'.
 *
 * The Initial Developer of the Original Code is Bruno Lowagie. Portions created by
 * the Initial Developer are Copyright (C) 1999, 2000, 2001, 2002 by Bruno Lowagie.
 * All Rights Reserved.
 * Co-Developer of the code is Paulo Soares. Portions created by the Co-Developer
 * are Copyright (C) 2000, 2001, 2002 by Paulo Soares. All Rights Reserved.
 *
 * Contributor(s): all the names of the contributors are added in the source code
 * where applicable.
 *
 * Alternatively, the contents of this file may be used under the terms of the
 * LGPL license (the "GNU LIBRARY GENERAL PUBLIC LICENSE"), in which case the
 * provisions of LGPL are applicable instead of those above.  If you wish to
 * allow use of your version of this file only under the terms of the LGPL
 * License and not to allow others to use your version of this file under
 * the MPL, indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by the LGPL.
 * If you do not delete the provisions above, a recipient may use your version
 * of this file under either the MPL or the GNU LIBRARY GENERAL PUBLIC LICENSE.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the MPL as stated above or under the terms of the GNU
 * Library General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Library general Public License for more
 * details.
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://www.lowagie.com/iText/
 */
package com.lowagie.tools.arguments;

import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;

import com.lowagie.tools.plugins.AbstractTool;

/**
 * Argument that allows you to select a (set of) page(s).
 */
public class PageSelectorToolArgument
    extends ToolArgument {
//  public final static String PROPERTYFILENAME = "inputfilename";
  public final static String PROPERTYPAGESELECTIONSTRING =
      "pageselectionstring";

  public PageSelectorToolArgument(AbstractTool tool, String name,
                                  String description,
                                  String classname) {
    super(tool, name, description, classname);

  }

  public void actionPerformed(ActionEvent e) {
    if (jDialog1 != null) {
      jDialog1.setVisible(true);
    }
  }

  public Object getArgument() throws InstantiationException {
    if (value == null) {
      return null;
    }
    return value;
  }

  public void propertyChange(PropertyChangeEvent evt) {
    String propertyname = evt.getPropertyName();
    if (jDialog1 == null) {
      actionPerformed(null);
    }
    if (propertyname == null) {
      return;
    }
    else if (propertyname.equals(name)) {
      String filename = (String) evt.getNewValue();
      if(jDialog1!=null)jDialog1.setVisible(false);
      jDialog1 = new PageSelectionTableDialog(tool.getInternalFrame());
      jDialog1.setVisible(true);
      jDialog1.addPropertyChangeListener(this);
      jDialog1.setDataModel(new PageTableModel(filename));
      jDialog1.setTitle(filename);
    }
    else if (propertyname.equals(PROPERTYPAGESELECTIONSTRING)) {
      String pageselectionstring = (String) evt.getNewValue();
      System.out.print(" Oldvalue:" + evt.getOldValue());
      System.out.println(" Newvalue:" + pageselectionstring);
      setValue(pageselectionstring, PROPERTYPAGESELECTIONSTRING);
    }
  }

  PageSelectionTableDialog jDialog1 = null;
}
